@@ -24,7 +24,7 @@ class ZombieNonClusterPolicies(NonClusterZombiePolicy):
                 logger.info(f'key: {cls[0]}, count: {len(response)}, {response}')
                 policy_result = response
                 if self._policy_output:
-                    if self._policy != 'ec2_idle':
+                    if self._policy not in ('ec2_idle', 'ebs_in_use', 'ec2_run'):
                         beautify_data = self._beautify_upload_data(upload_resource_data=response)
                         policy_result = {'count': len(beautify_data), self._policy: beautify_data}
                     logger.info(policy_result)
